# Pythonsay

Simple Python Cowsay implementation.

## Installation

    pip install pythonsay

## Usage

### Arguments

- -h, --help show this help message and exit
- -c, --cow print a cow
- -py, --python print a python
- -pb, --big print a big python

**Examples:**

    python pythonsay.py -c "Hello World"

    < Hello World! >
      ------------
           \   ^__^
            \  (oo)\_______
               (__)\       )\/\
                U  ||----w |
                   ||     ||

    python pythonsay.py -py "Hello World"


        < Hello World! >
        ____________
                \
                 \      /^\/^\
                  \   _|_O|  O|
              \/     /~     \_/ \
               \____|__________/  \
                    \_______      \
                            `\     \                 \
                             /     /                  \
                            /     /                    \
                          /     /                       \\
                        /     /                         \ \

    python pythonsay.py -pb "Hello World!"

    < Hello World! >
     ____________
          \
           \      /^\/^\
            \   _|_O|  O|
        \/     /~     \_/ \
         \____|__________/  \
               \_______      \
                       `\     \                 \
                        /     /                  \
                      /     /                    \
                    /     /                       \\
                   /     /                         \ \
                  /     /                            \  \
                 /     /             _----_            \   \
                /     /           _-~      ~-_         |   |
               (      (        _-~    _--_    ~-_     _/   |
                \      ~-____-~    _-~    ~-_    ~-_-~    /
                 ~-_           _-~          ~-_       _-~
                    ~--______-~                ~-___-~



                Art and idea by:  Tony Monroe

## About Cowsay

The original cowsay for GNU/Linux was written by Tony Monroe.

## About Pythonsay

The main idea is to use the cowsay program to complete the Python cicle from code to package, automated tests and documentation.
